@@ -1,7 +1,7 @@
 package Test::Perinci::CmdLine;
 
-our $DATE = '2015-06-17'; # DATE
-our $VERSION = '1.15'; # VERSION
+our $DATE = '2015-06-18'; # DATE
+our $VERSION = '1.16'; # VERSION
 
 use 5.010001;
 use strict;
@@ -125,11 +125,13 @@ sub pericmd_ok {
         );
     };
 
-    if (Test::More->builder->is_passing) {
+    if (!Test::More->builder->is_passing) {
+        diag "there are failing tests, not deleting tempdir $tempdir";
+    } elsif ($ENV{DEBUG}) {
+        diag "DEBUG is true, not deleting tempdir $tempdir";
+    } else {
         note "all tests successful, deleting tempdir $tempdir";
         remove_tree($tempdir);
-    } else {
-        diag "there are failing tests, not deleting tempdir $tempdir";
     }
 
 }
@@ -149,7 +151,7 @@ Test::Perinci::CmdLine - Common test suite for Perinci::CmdLine::{Lite,Classic,I
 
 =head1 VERSION
 
-This document describes version 1.15 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-17.
+This document describes version 1.16 of Test::Perinci::CmdLine (from Perl distribution Test-Perinci-CmdLine), released on 2015-06-18.
 
 =head1 SEE ALSO
 
